/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type atanhf_vec[] = {
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff33333, 0x33333333},	/* -nan=f(-1.2)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff30a3d, 0x70a3d70a},	/* -nan=f(-1.19)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff2e147, 0xae147ae1},	/* -nan=f(-1.18)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff2b851, 0xeb851eb8},	/* -nan=f(-1.17)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff28f5c, 0x28f5c28f},	/* -nan=f(-1.16)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff26666, 0x66666666},	/* -nan=f(-1.15)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff23d70, 0xa3d70a3d},	/* -nan=f(-1.14)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff2147a, 0xe147ae14},	/* -nan=f(-1.13)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff1eb85, 0x1eb851eb},	/* -nan=f(-1.12)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff1c28f, 0x5c28f5c2},	/* -nan=f(-1.11)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff19999, 0x99999999},	/* -nan=f(-1.1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff170a3, 0xd70a3d70},	/* -nan=f(-1.09)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff147ae, 0x147ae147},	/* -nan=f(-1.08)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff11eb8, 0x51eb851e},	/* -nan=f(-1.07)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff0f5c2, 0x8f5c28f5},	/* -nan=f(-1.06)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff0cccc, 0xcccccccc},	/* -nan=f(-1.05)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff0a3d7, 0x0a3d70a3},	/* -nan=f(-1.04)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff07ae1, 0x47ae147a},	/* -nan=f(-1.03)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff051eb, 0x851eb851},	/* -nan=f(-1.02)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff028f5, 0xc28f5c28},	/* -nan=f(-1.01)*/
{ 0, 0, 34,__LINE__, 0xfff00000, 0x00000000, 0xbfefffff, 0xfffffffe},	/* -inf=f(-1)*/
{37, 0,123,__LINE__, 0xc0052c58, 0x59ea246e, 0xbfefae14, 0x7ae147ac},	/* -2.64665=f(-0.99)*/
{37, 0,123,__LINE__, 0xc0026167, 0x59bb9de0, 0xbfef5c28, 0xf5c28f5a},	/* -2.29756=f(-0.98)*/
{36, 0,123,__LINE__, 0xc000bd05, 0xcad265a5, 0xbfef0a3d, 0x70a3d708},	/* -2.0923=f(-0.97)*/
{37, 0,123,__LINE__, 0xbfff2272, 0x64ba31cf, 0xbfeeb851, 0xeb851eb6},	/* -1.94591=f(-0.96)*/
{37, 0,123,__LINE__, 0xbffd4ef9, 0x47b600f5, 0xbfee6666, 0x66666664},	/* -1.83178=f(-0.95)*/
{36, 0,123,__LINE__, 0xbffbcf0c, 0xcef48707, 0xbfee147a, 0xe147ae12},	/* -1.73805=f(-0.94)*/
{37, 0,123,__LINE__, 0xbffa88c4, 0x076fa149, 0xbfedc28f, 0x5c28f5c0},	/* -1.65839=f(-0.93)*/
{37, 0,123,__LINE__, 0xbff96ca7, 0x99bcd7d4, 0xbfed70a3, 0xd70a3d6e},	/* -1.58903=f(-0.92)*/
{38, 0,123,__LINE__, 0xbff870bd, 0x9ca01af3, 0xbfed1eb8, 0x51eb851c},	/* -1.52752=f(-0.91)*/
{37, 0,123,__LINE__, 0xbff78e35, 0xe4558b00, 0xbfeccccc, 0xccccccca},	/* -1.47222=f(-0.9)*/
{37, 0,123,__LINE__, 0xbff6c035, 0x45250d2b, 0xbfec7ae1, 0x47ae1478},	/* -1.42193=f(-0.89)*/
{36, 0,123,__LINE__, 0xbff60324, 0xec8df3bd, 0xbfec28f5, 0xc28f5c26},	/* -1.37577=f(-0.88)*/
{36, 0,123,__LINE__, 0xbff5544b, 0x538c16aa, 0xbfebd70a, 0x3d70a3d4},	/* -1.33308=f(-0.87)*/
{38, 0,123,__LINE__, 0xbff4b18a, 0x3d8d9d3d, 0xbfeb851e, 0xb851eb82},	/* -1.29334=f(-0.86)*/
{37, 0,123,__LINE__, 0xbff41933, 0xc7f46b3b, 0xbfeb3333, 0x33333330},	/* -1.25615=f(-0.85)*/
{37, 0,123,__LINE__, 0xbff389ed, 0x2629685b, 0xbfeae147, 0xae147ade},	/* -1.22117=f(-0.84)*/
{38, 0,123,__LINE__, 0xbff3029b, 0x431a5215, 0xbfea8f5c, 0x28f5c28c},	/* -1.18814=f(-0.83)*/
{39, 0,123,__LINE__, 0xbff28253, 0x01c158ae, 0xbfea3d70, 0xa3d70a3a},	/* -1.15682=f(-0.82)*/
{37, 0,123,__LINE__, 0xbff2084f, 0x9864d60e, 0xbfe9eb85, 0x1eb851e8},	/* -1.12703=f(-0.81)*/
{38, 0,123,__LINE__, 0xbff193ea, 0x83909147, 0xbfe99999, 0x99999996},	/* -1.09861=f(-0.8)*/
{38, 0,123,__LINE__, 0xbff12495, 0x9c01a0de, 0xbfe947ae, 0x147ae144},	/* -1.07143=f(-0.79)*/
{37, 0,123,__LINE__, 0xbff0b9d6, 0x64413c94, 0xbfe8f5c2, 0x8f5c28f2},	/* -1.04537=f(-0.78)*/
{37, 0,123,__LINE__, 0xbff05343, 0x267f79da, 0xbfe8a3d7, 0x0a3d70a0},	/* -1.02033=f(-0.77)*/
{37, 0,123,__LINE__, 0xbfefe0fe, 0x67af80c6, 0xbfe851eb, 0x851eb84e},	/* -0.996215=f(-0.76)*/
{36, 0,123,__LINE__, 0xbfef2272, 0xae325a57, 0xbfe7ffff, 0xfffffffc},	/* -0.972955=f(-0.75)*/
{37, 0,123,__LINE__, 0xbfee6a53, 0xc73728fb, 0xbfe7ae14, 0x7ae147aa},	/* -0.950479=f(-0.74)*/
{36, 0,123,__LINE__, 0xbfedb822, 0x88f70a04, 0xbfe75c28, 0xf5c28f58},	/* -0.928727=f(-0.73)*/
{38, 0,123,__LINE__, 0xbfed0b6d, 0x9ddc4699, 0xbfe70a3d, 0x70a3d706},	/* -0.907645=f(-0.72)*/
{35, 0,123,__LINE__, 0xbfec63cf, 0x528c6ed8, 0xbfe6b851, 0xeb851eb4},	/* -0.887184=f(-0.71)*/
{38, 0,123,__LINE__, 0xbfebc0ec, 0xfcbb6f60, 0xbfe66666, 0x66666662},	/* -0.867301=f(-0.7)*/
{37, 0,123,__LINE__, 0xbfeb2274, 0x19326411, 0xbfe6147a, 0xe147ae10},	/* -0.847956=f(-0.69)*/
{35, 0,123,__LINE__, 0xbfea881a, 0x3109b5bd, 0xbfe5c28f, 0x5c28f5be},	/* -0.829114=f(-0.68)*/
{39, 0,123,__LINE__, 0xbfe9f19b, 0xa16e11de, 0xbfe570a3, 0xd70a3d6c},	/* -0.810743=f(-0.67)*/
{36, 0,123,__LINE__, 0xbfe95eba, 0xca88f7a3, 0xbfe51eb8, 0x51eb851a},	/* -0.792814=f(-0.66)*/
{37, 0,123,__LINE__, 0xbfe8cf3f, 0x254efa84, 0xbfe4cccc, 0xccccccc8},	/* -0.775299=f(-0.65)*/
{36, 0,123,__LINE__, 0xbfe842f5, 0x88c13db9, 0xbfe47ae1, 0x47ae1476},	/* -0.758174=f(-0.64)*/
{36, 0,123,__LINE__, 0xbfe7b9ae, 0x55331f75, 0xbfe428f5, 0xc28f5c24},	/* -0.741416=f(-0.63)*/
{38, 0,123,__LINE__, 0xbfe7333d, 0xe2d33c31, 0xbfe3d70a, 0x3d70a3d2},	/* -0.725005=f(-0.62)*/
{37, 0,123,__LINE__, 0xbfe6af7b, 0xe500d98f, 0xbfe3851e, 0xb851eb80},	/* -0.708921=f(-0.61)*/
{35, 0,123,__LINE__, 0xbfe62e43, 0x12fa39f7, 0xbfe33333, 0x3333332e},	/* -0.693147=f(-0.6)*/
{36, 0,123,__LINE__, 0xbfe5af70, 0xaa3af2c1, 0xbfe2e147, 0xae147adc},	/* -0.677666=f(-0.59)*/
{35, 0,123,__LINE__, 0xbfe532e4, 0xf05ede2a, 0xbfe28f5c, 0x28f5c28a},	/* -0.662463=f(-0.58)*/
{36, 0,123,__LINE__, 0xbfe4b881, 0xce8e2584, 0xbfe23d70, 0xa3d70a38},	/* -0.647523=f(-0.57)*/
{38, 0,123,__LINE__, 0xbfe4402b, 0x63ef10bd, 0xbfe1eb85, 0x1eb851e6},	/* -0.632833=f(-0.56)*/
{37, 0,123,__LINE__, 0xbfe3c9c7, 0xa4f54688, 0xbfe19999, 0x99999994},	/* -0.618381=f(-0.55)*/
{35, 0,123,__LINE__, 0xbfe3553e, 0x31d0736f, 0xbfe147ae, 0x147ae142},	/* -0.604156=f(-0.54)*/
{37, 0,123,__LINE__, 0xbfe2e278, 0x04d0f87e, 0xbfe0f5c2, 0x8f5c28f0},	/* -0.590145=f(-0.53)*/
{38, 0,123,__LINE__, 0xbfe27160, 0x03d64ad8, 0xbfe0a3d7, 0x0a3d709e},	/* -0.57634=f(-0.52)*/
{36, 0,123,__LINE__, 0xbfe201e1, 0xd58fd110, 0xbfe051eb, 0x851eb84c},	/* -0.56273=f(-0.51)*/
{37, 0,123,__LINE__, 0xbfe193ea, 0x7aad030b, 0xbfdfffff, 0xfffffff4},	/* -0.549306=f(-0.5)*/
{36, 0,123,__LINE__, 0xbfe12768, 0x088a767f, 0xbfdf5c28, 0xf5c28f50},	/* -0.53606=f(-0.49)*/
{39, 0,123,__LINE__, 0xbfe0bc49, 0x7e9674b8, 0xbfdeb851, 0xeb851eac},	/* -0.522984=f(-0.48)*/
{37, 0,123,__LINE__, 0xbfe0527f, 0x05faf325, 0xbfde147a, 0xe147ae08},	/* -0.51007=f(-0.47)*/
{37, 0,123,__LINE__, 0xbfdfd3f2, 0xc460cfca, 0xbfdd70a3, 0xd70a3d64},	/* -0.497311=f(-0.46)*/
{34, 0,123,__LINE__, 0xbfdf0554, 0x412e443b, 0xbfdccccc, 0xccccccc0},	/* -0.4847=f(-0.45)*/
{36, 0,123,__LINE__, 0xbfde3907, 0x8a1cdea0, 0xbfdc28f5, 0xc28f5c1c},	/* -0.472231=f(-0.44)*/
{37, 0,123,__LINE__, 0xbfdd6ef2, 0x86c24e24, 0xbfdb851e, 0xb851eb78},	/* -0.459897=f(-0.43)*/
{40, 0,123,__LINE__, 0xbfdca6fc, 0x60d63f7c, 0xbfdae147, 0xae147ad4},	/* -0.447692=f(-0.42)*/
{40, 0,123,__LINE__, 0xbfdbe10d, 0xe0c6cef4, 0xbfda3d70, 0xa3d70a30},	/* -0.435611=f(-0.41)*/
{36, 0,123,__LINE__, 0xbfdb1d10, 0x6ea92881, 0xbfd99999, 0x9999998c},	/* -0.423649=f(-0.4)*/
{35, 0,123,__LINE__, 0xbfda5aee, 0x76077102, 0xbfd8f5c2, 0x8f5c28e8},	/* -0.4118=f(-0.39)*/
{37, 0,123,__LINE__, 0xbfd99a93, 0xc4603a24, 0xbfd851eb, 0x851eb844},	/* -0.40006=f(-0.38)*/
{36, 0,123,__LINE__, 0xbfd8dbec, 0x9581e280, 0xbfd7ae14, 0x7ae147a0},	/* -0.388423=f(-0.37)*/
{38, 0,123,__LINE__, 0xbfd81ee6, 0x1ca0f5c1, 0xbfd70a3d, 0x70a3d6fc},	/* -0.376886=f(-0.36)*/
{36, 0,123,__LINE__, 0xbfd7636e, 0x2bfcc19f, 0xbfd66666, 0x66666658},	/* -0.365444=f(-0.35)*/
{35, 0,123,__LINE__, 0xbfd6a973, 0xba412eaa, 0xbfd5c28f, 0x5c28f5b4},	/* -0.354093=f(-0.34)*/
{37, 0,123,__LINE__, 0xbfd5f0e5, 0xfb03f25d, 0xbfd51eb8, 0x51eb8510},	/* -0.342828=f(-0.33)*/
{38, 0,123,__LINE__, 0xbfd539b4, 0xc2de8589, 0xbfd47ae1, 0x47ae146c},	/* -0.331647=f(-0.32)*/
{37, 0,123,__LINE__, 0xbfd483d0, 0xe74a7672, 0xbfd3d70a, 0x3d70a3c8},	/* -0.320545=f(-0.31)*/
{39, 0,123,__LINE__, 0xbfd3cf2b, 0x5e725da4, 0xbfd33333, 0x33333324},	/* -0.30952=f(-0.3)*/
{38, 0,123,__LINE__, 0xbfd31bb5, 0xa2be9f40, 0xbfd28f5c, 0x28f5c280},	/* -0.298566=f(-0.29)*/
{36, 0,123,__LINE__, 0xbfd26962, 0x129869cb, 0xbfd1eb85, 0x1eb851dc},	/* -0.287682=f(-0.28)*/
{36, 0,123,__LINE__, 0xbfd1b823, 0x165cf6fd, 0xbfd147ae, 0x147ae138},	/* -0.276864=f(-0.27)*/
{38, 0,123,__LINE__, 0xbfd107eb, 0x8332229b, 0xbfd0a3d7, 0x0a3d7094},	/* -0.266108=f(-0.26)*/
{37, 0,123,__LINE__, 0xbfd058ae, 0xfa811452, 0xbfcfffff, 0xffffffe0},	/* -0.255413=f(-0.25)*/
{36, 0,123,__LINE__, 0xbfcf54c2, 0x082a623d, 0xbfceb851, 0xeb851e98},	/* -0.244774=f(-0.24)*/
{35, 0,123,__LINE__, 0xbfcdf9eb, 0xabdc2b74, 0xbfcd70a3, 0xd70a3d50},	/* -0.234189=f(-0.23)*/
{36, 0,123,__LINE__, 0xbfcca0c3, 0x6a35a0c5, 0xbfcc28f5, 0xc28f5c08},	/* -0.223656=f(-0.22)*/
{36, 0,123,__LINE__, 0xbfcb4932, 0xce3d982c, 0xbfcae147, 0xae147ac0},	/* -0.213171=f(-0.21)*/
{35, 0,123,__LINE__, 0xbfc9f323, 0xf36a42f7, 0xbfc99999, 0x99999978},	/* -0.202733=f(-0.2)*/
{37, 0,123,__LINE__, 0xbfc89e81, 0x187d6561, 0xbfc851eb, 0x851eb830},	/* -0.192337=f(-0.19)*/
{42, 0,123,__LINE__, 0xbfc74b35, 0x7fdd0918, 0xbfc70a3d, 0x70a3d6e8},	/* -0.181983=f(-0.18)*/
{38, 0,123,__LINE__, 0xbfc5f92c, 0x5cba7e5e, 0xbfc5c28f, 0x5c28f5a0},	/* -0.171667=f(-0.17)*/
{35, 0,123,__LINE__, 0xbfc4a851, 0xb310bf88, 0xbfc47ae1, 0x47ae1458},	/* -0.161387=f(-0.16)*/
{36, 0,123,__LINE__, 0xbfc35891, 0xebd1dd50, 0xbfc33333, 0x33333310},	/* -0.15114=f(-0.15)*/
{35, 0,123,__LINE__, 0xbfc209d9, 0x6b808023, 0xbfc1eb85, 0x1eb851c8},	/* -0.140926=f(-0.14)*/
{35, 0,123,__LINE__, 0xbfc0bc15, 0x4fa9b79b, 0xbfc0a3d7, 0x0a3d7080},	/* -0.13074=f(-0.13)*/
{36, 0,123,__LINE__, 0xbfbede65, 0xe9d8108a, 0xbfbeb851, 0xeb851e71},	/* -0.120581=f(-0.12)*/
{40, 0,123,__LINE__, 0xbfbc463f, 0xc0abd250, 0xbfbc28f5, 0xc28f5be2},	/* -0.110447=f(-0.11)*/
{36, 0,123,__LINE__, 0xbfb9af93, 0xd39a3724, 0xbfb99999, 0x99999953},	/* -0.100335=f(-0.1)*/
{36, 0,123,__LINE__, 0xbfb71a3e, 0x4afb4e44, 0xbfb70a3d, 0x70a3d6c4},	/* -0.0902442=f(-0.09)*/
{35, 0,123,__LINE__, 0xbfb4861b, 0x9b624b89, 0xbfb47ae1, 0x47ae1435},	/* -0.0801713=f(-0.08)*/
{37, 0,123,__LINE__, 0xbfb1f308, 0xfab768a0, 0xbfb1eb85, 0x1eb851a6},	/* -0.0701147=f(-0.07)*/
{35, 0,123,__LINE__, 0xbfaec1c7, 0x0699b818, 0xbfaeb851, 0xeb851e2d},	/* -0.0600722=f(-0.06)*/
{35, 0,123,__LINE__, 0xbfa99f11, 0xd3c9f22b, 0xbfa99999, 0x9999990e},	/* -0.0500417=f(-0.05)*/
{37, 0,123,__LINE__, 0xbfa47dad, 0xc40c7f6f, 0xbfa47ae1, 0x47ae13ef},	/* -0.0400214=f(-0.04)*/
{35, 0,123,__LINE__, 0xbf9ebaae, 0x2e5c3324, 0xbf9eb851, 0xeb851da0},	/* -0.030009=f(-0.03)*/
{45, 0,123,__LINE__, 0xbf947b94, 0x3ffacc0e, 0xbf947ae1, 0x47ae1362},	/* -0.0200027=f(-0.02)*/
{38, 0,123,__LINE__, 0xbf847b0d, 0xfdeebec6, 0xbf847ae1, 0x47ae1249},	/* -0.0100003=f(-0.01)*/
{64, 0,123,__LINE__, 0x3cd19000, 0x00000000, 0x3cd19000, 0x00000000},	/* 9.74915e-16=f(9.74915e-16)*/
{38, 0,123,__LINE__, 0x3f847b0d, 0xfdeebec6, 0x3f847ae1, 0x47ae16ad},	/* 0.0100003=f(0.01)*/
{45, 0,123,__LINE__, 0x3f947b94, 0x3ffacc0e, 0x3f947ae1, 0x47ae1594},	/* 0.0200027=f(0.02)*/
{35, 0,123,__LINE__, 0x3f9ebaae, 0x2e5c3324, 0x3f9eb851, 0xeb851fd2},	/* 0.030009=f(0.03)*/
{37, 0,123,__LINE__, 0x3fa47dad, 0xc40c7f6f, 0x3fa47ae1, 0x47ae1508},	/* 0.0400214=f(0.04)*/
{35, 0,123,__LINE__, 0x3fa99f11, 0xd3c9f22b, 0x3fa99999, 0x99999a27},	/* 0.0500417=f(0.05)*/
{35, 0,123,__LINE__, 0x3faec1c7, 0x0699b818, 0x3faeb851, 0xeb851f46},	/* 0.0600722=f(0.06)*/
{37, 0,123,__LINE__, 0x3fb1f308, 0xfab768a0, 0x3fb1eb85, 0x1eb85232},	/* 0.0701147=f(0.07)*/
{35, 0,123,__LINE__, 0x3fb4861b, 0x9b624b89, 0x3fb47ae1, 0x47ae14c1},	/* 0.0801713=f(0.08)*/
{36, 0,123,__LINE__, 0x3fb71a3e, 0x4afb4e44, 0x3fb70a3d, 0x70a3d750},	/* 0.0902442=f(0.09)*/
{36, 0,123,__LINE__, 0x3fb9af93, 0xd39a3724, 0x3fb99999, 0x999999df},	/* 0.100335=f(0.1)*/
{40, 0,123,__LINE__, 0x3fbc463f, 0xc0abd250, 0x3fbc28f5, 0xc28f5c6e},	/* 0.110447=f(0.11)*/
{36, 0,123,__LINE__, 0x3fbede65, 0xe9d8108a, 0x3fbeb851, 0xeb851efd},	/* 0.120581=f(0.12)*/
{35, 0,123,__LINE__, 0x3fc0bc15, 0x4fa9b79b, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.13074=f(0.13)*/
{35, 0,123,__LINE__, 0x3fc209d9, 0x6b808023, 0x3fc1eb85, 0x1eb8520e},	/* 0.140926=f(0.14)*/
{36, 0,123,__LINE__, 0x3fc35891, 0xebd1dd50, 0x3fc33333, 0x33333356},	/* 0.15114=f(0.15)*/
{35, 0,123,__LINE__, 0x3fc4a851, 0xb310bf88, 0x3fc47ae1, 0x47ae149e},	/* 0.161387=f(0.16)*/
{38, 0,123,__LINE__, 0x3fc5f92c, 0x5cba7e5e, 0x3fc5c28f, 0x5c28f5e6},	/* 0.171667=f(0.17)*/
{42, 0,123,__LINE__, 0x3fc74b35, 0x7fdd0918, 0x3fc70a3d, 0x70a3d72e},	/* 0.181983=f(0.18)*/
{37, 0,123,__LINE__, 0x3fc89e81, 0x187d6561, 0x3fc851eb, 0x851eb876},	/* 0.192337=f(0.19)*/
{35, 0,123,__LINE__, 0x3fc9f323, 0xf36a42f7, 0x3fc99999, 0x999999be},	/* 0.202733=f(0.2)*/
{36, 0,123,__LINE__, 0x3fcb4932, 0xce3d982c, 0x3fcae147, 0xae147b06},	/* 0.213171=f(0.21)*/
{36, 0,123,__LINE__, 0x3fcca0c3, 0x6a35a0c5, 0x3fcc28f5, 0xc28f5c4e},	/* 0.223656=f(0.22)*/
{35, 0,123,__LINE__, 0x3fcdf9eb, 0xabdc2b74, 0x3fcd70a3, 0xd70a3d96},	/* 0.234189=f(0.23)*/
{36, 0,123,__LINE__, 0x3fcf54c2, 0x082a623d, 0x3fceb851, 0xeb851ede},	/* 0.244774=f(0.24)*/
{37, 0,123,__LINE__, 0x3fd058ae, 0xfa811452, 0x3fd00000, 0x00000013},	/* 0.255413=f(0.25)*/
{38, 0,123,__LINE__, 0x3fd107eb, 0x8332229b, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.266108=f(0.26)*/
{36, 0,123,__LINE__, 0x3fd1b823, 0x165cf6fd, 0x3fd147ae, 0x147ae15b},	/* 0.276864=f(0.27)*/
{36, 0,123,__LINE__, 0x3fd26962, 0x129869cb, 0x3fd1eb85, 0x1eb851ff},	/* 0.287682=f(0.28)*/
{38, 0,123,__LINE__, 0x3fd31bb5, 0xa2be9f40, 0x3fd28f5c, 0x28f5c2a3},	/* 0.298566=f(0.29)*/
{39, 0,123,__LINE__, 0x3fd3cf2b, 0x5e725da4, 0x3fd33333, 0x33333347},	/* 0.30952=f(0.3)*/
{37, 0,123,__LINE__, 0x3fd483d0, 0xe74a7672, 0x3fd3d70a, 0x3d70a3eb},	/* 0.320545=f(0.31)*/
{38, 0,123,__LINE__, 0x3fd539b4, 0xc2de8589, 0x3fd47ae1, 0x47ae148f},	/* 0.331647=f(0.32)*/
{37, 0,123,__LINE__, 0x3fd5f0e5, 0xfb03f25d, 0x3fd51eb8, 0x51eb8533},	/* 0.342828=f(0.33)*/
{35, 0,123,__LINE__, 0x3fd6a973, 0xba412eaa, 0x3fd5c28f, 0x5c28f5d7},	/* 0.354093=f(0.34)*/
{36, 0,123,__LINE__, 0x3fd7636e, 0x2bfcc19f, 0x3fd66666, 0x6666667b},	/* 0.365444=f(0.35)*/
{38, 0,123,__LINE__, 0x3fd81ee6, 0x1ca0f5c1, 0x3fd70a3d, 0x70a3d71f},	/* 0.376886=f(0.36)*/
{36, 0,123,__LINE__, 0x3fd8dbec, 0x9581e280, 0x3fd7ae14, 0x7ae147c3},	/* 0.388423=f(0.37)*/
{37, 0,123,__LINE__, 0x3fd99a93, 0xc4603a24, 0x3fd851eb, 0x851eb867},	/* 0.40006=f(0.38)*/
{35, 0,123,__LINE__, 0x3fda5aee, 0x76077102, 0x3fd8f5c2, 0x8f5c290b},	/* 0.4118=f(0.39)*/
{36, 0,123,__LINE__, 0x3fdb1d10, 0x6ea92881, 0x3fd99999, 0x999999af},	/* 0.423649=f(0.4)*/
{40, 0,123,__LINE__, 0x3fdbe10d, 0xe0c6cef4, 0x3fda3d70, 0xa3d70a53},	/* 0.435611=f(0.41)*/
{40, 0,123,__LINE__, 0x3fdca6fc, 0x60d63f7c, 0x3fdae147, 0xae147af7},	/* 0.447692=f(0.42)*/
{37, 0,123,__LINE__, 0x3fdd6ef2, 0x86c24e24, 0x3fdb851e, 0xb851eb9b},	/* 0.459897=f(0.43)*/
{36, 0,123,__LINE__, 0x3fde3907, 0x8a1cdea0, 0x3fdc28f5, 0xc28f5c3f},	/* 0.472231=f(0.44)*/
{34, 0,123,__LINE__, 0x3fdf0554, 0x412e443b, 0x3fdccccc, 0xcccccce3},	/* 0.4847=f(0.45)*/
{37, 0,123,__LINE__, 0x3fdfd3f2, 0xc460cfca, 0x3fdd70a3, 0xd70a3d87},	/* 0.497311=f(0.46)*/
{37, 0,123,__LINE__, 0x3fe0527f, 0x05faf325, 0x3fde147a, 0xe147ae2b},	/* 0.51007=f(0.47)*/
{39, 0,123,__LINE__, 0x3fe0bc49, 0x7e9674b8, 0x3fdeb851, 0xeb851ecf},	/* 0.522984=f(0.48)*/
{36, 0,123,__LINE__, 0x3fe12768, 0x088a767f, 0x3fdf5c28, 0xf5c28f73},	/* 0.53606=f(0.49)*/
{37, 0,123,__LINE__, 0x3fe193ea, 0x7aad030b, 0x3fe00000, 0x0000000b},	/* 0.549306=f(0.5)*/
{36, 0,123,__LINE__, 0x3fe201e1, 0xd58fd110, 0x3fe051eb, 0x851eb85d},	/* 0.56273=f(0.51)*/
{38, 0,123,__LINE__, 0x3fe27160, 0x03d64ad8, 0x3fe0a3d7, 0x0a3d70af},	/* 0.57634=f(0.52)*/
{37, 0,123,__LINE__, 0x3fe2e278, 0x04d0f87e, 0x3fe0f5c2, 0x8f5c2901},	/* 0.590145=f(0.53)*/
{35, 0,123,__LINE__, 0x3fe3553e, 0x31d0736f, 0x3fe147ae, 0x147ae153},	/* 0.604156=f(0.54)*/
{37, 0,123,__LINE__, 0x3fe3c9c7, 0xa4f54688, 0x3fe19999, 0x999999a5},	/* 0.618381=f(0.55)*/
{38, 0,123,__LINE__, 0x3fe4402b, 0x63ef10bd, 0x3fe1eb85, 0x1eb851f7},	/* 0.632833=f(0.56)*/
{36, 0,123,__LINE__, 0x3fe4b881, 0xce8e2584, 0x3fe23d70, 0xa3d70a49},	/* 0.647523=f(0.57)*/
{35, 0,123,__LINE__, 0x3fe532e4, 0xf05ede2a, 0x3fe28f5c, 0x28f5c29b},	/* 0.662463=f(0.58)*/
{36, 0,123,__LINE__, 0x3fe5af70, 0xaa3af2c1, 0x3fe2e147, 0xae147aed},	/* 0.677666=f(0.59)*/
{35, 0,123,__LINE__, 0x3fe62e43, 0x12fa39f7, 0x3fe33333, 0x3333333f},	/* 0.693147=f(0.6)*/
{37, 0,123,__LINE__, 0x3fe6af7b, 0xe500d98f, 0x3fe3851e, 0xb851eb91},	/* 0.708921=f(0.61)*/
{38, 0,123,__LINE__, 0x3fe7333d, 0xe2d33c31, 0x3fe3d70a, 0x3d70a3e3},	/* 0.725005=f(0.62)*/
{36, 0,123,__LINE__, 0x3fe7b9ae, 0x55331f75, 0x3fe428f5, 0xc28f5c35},	/* 0.741416=f(0.63)*/
{36, 0,123,__LINE__, 0x3fe842f5, 0x88c13db9, 0x3fe47ae1, 0x47ae1487},	/* 0.758174=f(0.64)*/
{37, 0,123,__LINE__, 0x3fe8cf3f, 0x254efa84, 0x3fe4cccc, 0xccccccd9},	/* 0.775299=f(0.65)*/
{36, 0,123,__LINE__, 0x3fe95eba, 0xca88f7a3, 0x3fe51eb8, 0x51eb852b},	/* 0.792814=f(0.66)*/
{39, 0,123,__LINE__, 0x3fe9f19b, 0xa16e11de, 0x3fe570a3, 0xd70a3d7d},	/* 0.810743=f(0.67)*/
{35, 0,123,__LINE__, 0x3fea881a, 0x3109b5bd, 0x3fe5c28f, 0x5c28f5cf},	/* 0.829114=f(0.68)*/
{37, 0,123,__LINE__, 0x3feb2274, 0x19326411, 0x3fe6147a, 0xe147ae21},	/* 0.847956=f(0.69)*/
{38, 0,123,__LINE__, 0x3febc0ec, 0xfcbb6f60, 0x3fe66666, 0x66666673},	/* 0.867301=f(0.7)*/
{35, 0,123,__LINE__, 0x3fec63cf, 0x528c6ed8, 0x3fe6b851, 0xeb851ec5},	/* 0.887184=f(0.71)*/
{38, 0,123,__LINE__, 0x3fed0b6d, 0x9ddc4699, 0x3fe70a3d, 0x70a3d717},	/* 0.907645=f(0.72)*/
{36, 0,123,__LINE__, 0x3fedb822, 0x88f70a04, 0x3fe75c28, 0xf5c28f69},	/* 0.928727=f(0.73)*/
{37, 0,123,__LINE__, 0x3fee6a53, 0xc73728fb, 0x3fe7ae14, 0x7ae147bb},	/* 0.950479=f(0.74)*/
{36, 0,123,__LINE__, 0x3fef2272, 0xae325a57, 0x3fe80000, 0x0000000d},	/* 0.972955=f(0.75)*/
{37, 0,123,__LINE__, 0x3fefe0fe, 0x67af80c6, 0x3fe851eb, 0x851eb85f},	/* 0.996215=f(0.76)*/
{37, 0,123,__LINE__, 0x3ff05343, 0x267f79da, 0x3fe8a3d7, 0x0a3d70b1},	/* 1.02033=f(0.77)*/
{37, 0,123,__LINE__, 0x3ff0b9d6, 0x64413c94, 0x3fe8f5c2, 0x8f5c2903},	/* 1.04537=f(0.78)*/
{38, 0,123,__LINE__, 0x3ff12495, 0x9c01a0de, 0x3fe947ae, 0x147ae155},	/* 1.07143=f(0.79)*/
{38, 0,123,__LINE__, 0x3ff193ea, 0x83909147, 0x3fe99999, 0x999999a7},	/* 1.09861=f(0.8)*/
{37, 0,123,__LINE__, 0x3ff2084f, 0x9864d60e, 0x3fe9eb85, 0x1eb851f9},	/* 1.12703=f(0.81)*/
{39, 0,123,__LINE__, 0x3ff28253, 0x01c158ae, 0x3fea3d70, 0xa3d70a4b},	/* 1.15682=f(0.82)*/
{38, 0,123,__LINE__, 0x3ff3029b, 0x431a5215, 0x3fea8f5c, 0x28f5c29d},	/* 1.18814=f(0.83)*/
{37, 0,123,__LINE__, 0x3ff389ed, 0x2629685b, 0x3feae147, 0xae147aef},	/* 1.22117=f(0.84)*/
{37, 0,123,__LINE__, 0x3ff41933, 0xc7f46b3b, 0x3feb3333, 0x33333341},	/* 1.25615=f(0.85)*/
{38, 0,123,__LINE__, 0x3ff4b18a, 0x3d8d9d3d, 0x3feb851e, 0xb851eb93},	/* 1.29334=f(0.86)*/
{36, 0,123,__LINE__, 0x3ff5544b, 0x538c16aa, 0x3febd70a, 0x3d70a3e5},	/* 1.33308=f(0.87)*/
{36, 0,123,__LINE__, 0x3ff60324, 0xec8df3bd, 0x3fec28f5, 0xc28f5c37},	/* 1.37577=f(0.88)*/
{37, 0,123,__LINE__, 0x3ff6c035, 0x45250d2b, 0x3fec7ae1, 0x47ae1489},	/* 1.42193=f(0.89)*/
{37, 0,123,__LINE__, 0x3ff78e35, 0xe4558b00, 0x3feccccc, 0xccccccdb},	/* 1.47222=f(0.9)*/
{38, 0,123,__LINE__, 0x3ff870bd, 0x9ca01af3, 0x3fed1eb8, 0x51eb852d},	/* 1.52752=f(0.91)*/
{37, 0,123,__LINE__, 0x3ff96ca7, 0x99bcd7d4, 0x3fed70a3, 0xd70a3d7f},	/* 1.58903=f(0.92)*/
{37, 0,123,__LINE__, 0x3ffa88c4, 0x076fa149, 0x3fedc28f, 0x5c28f5d1},	/* 1.65839=f(0.93)*/
{36, 0,123,__LINE__, 0x3ffbcf0c, 0xcef48707, 0x3fee147a, 0xe147ae23},	/* 1.73805=f(0.94)*/
{37, 0,123,__LINE__, 0x3ffd4ef9, 0x47b600f5, 0x3fee6666, 0x66666675},	/* 1.83178=f(0.95)*/
{37, 0,123,__LINE__, 0x3fff2272, 0x64ba31cf, 0x3feeb851, 0xeb851ec7},	/* 1.94591=f(0.96)*/
{36, 0,123,__LINE__, 0x4000bd05, 0xcad265a5, 0x3fef0a3d, 0x70a3d719},	/* 2.0923=f(0.97)*/
{37, 0,123,__LINE__, 0x40026167, 0x59bb9de0, 0x3fef5c28, 0xf5c28f6b},	/* 2.29756=f(0.98)*/
{37, 0,123,__LINE__, 0x40052c58, 0x59ea246e, 0x3fefae14, 0x7ae147bd},	/* 2.64665=f(0.99)*/
{31, 0, 34,__LINE__, 0x7ff00000, 0x00000000, 0x3ff00000, 0x00000007},	/* inf=f(1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff028f5, 0xc28f5c30},	/* -nan=f(1.01)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff051eb, 0x851eb859},	/* -nan=f(1.02)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff07ae1, 0x47ae1482},	/* -nan=f(1.03)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff0a3d7, 0x0a3d70ab},	/* -nan=f(1.04)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff0cccc, 0xccccccd4},	/* -nan=f(1.05)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff0f5c2, 0x8f5c28fd},	/* -nan=f(1.06)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff11eb8, 0x51eb8526},	/* -nan=f(1.07)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff147ae, 0x147ae14f},	/* -nan=f(1.08)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff170a3, 0xd70a3d78},	/* -nan=f(1.09)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff19999, 0x999999a1},	/* -nan=f(1.1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff1c28f, 0x5c28f5ca},	/* -nan=f(1.11)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff1eb85, 0x1eb851f3},	/* -nan=f(1.12)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff2147a, 0xe147ae1c},	/* -nan=f(1.13)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff23d70, 0xa3d70a45},	/* -nan=f(1.14)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff26666, 0x6666666e},	/* -nan=f(1.15)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff28f5c, 0x28f5c297},	/* -nan=f(1.16)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff2b851, 0xeb851ec0},	/* -nan=f(1.17)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff2e147, 0xae147ae9},	/* -nan=f(1.18)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff30a3d, 0x70a3d712},	/* -nan=f(1.19)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc01921fb, 0x54442d18},	/* -nan=f(-6.28319)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc012d97c, 0x7f3321d2},	/* -nan=f(-4.71239)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc00921fb, 0x54442d18},	/* -nan=f(-3.14159)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff921fb, 0x54442d18},	/* -nan=f(-1.5708)*/
{64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},	/* 0=f(0)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x3ff921fb, 0x54442d18},	/* -nan=f(1.5708)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x400921fb, 0x54442d18},	/* -nan=f(3.14159)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x4012d97c, 0x7f3321d2},	/* -nan=f(4.71239)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc03e0000, 0x00000000},	/* -nan=f(-30)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc03c4ccc, 0xcccccccd},	/* -nan=f(-28.3)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc03a9999, 0x9999999a},	/* -nan=f(-26.6)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc038e666, 0x66666667},	/* -nan=f(-24.9)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0373333, 0x33333334},	/* -nan=f(-23.2)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0358000, 0x00000001},	/* -nan=f(-21.5)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc033cccc, 0xccccccce},	/* -nan=f(-19.8)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0321999, 0x9999999b},	/* -nan=f(-18.1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0306666, 0x66666668},	/* -nan=f(-16.4)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc02d6666, 0x6666666a},	/* -nan=f(-14.7)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc02a0000, 0x00000004},	/* -nan=f(-13)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0269999, 0x9999999e},	/* -nan=f(-11.3)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0233333, 0x33333338},	/* -nan=f(-9.6)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc01f9999, 0x999999a3},	/* -nan=f(-7.9)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc018cccc, 0xccccccd6},	/* -nan=f(-6.2)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0120000, 0x00000009},	/* -nan=f(-4.5)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xc0066666, 0x66666678},	/* -nan=f(-2.8)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0xbff19999, 0x999999bd},	/* -nan=f(-1.1)*/
{35, 0,123,__LINE__, 0x3fe62e43, 0x12fa39f7, 0x3fe33333, 0x333332ec},	/* 0.693147=f(0.6)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40026666, 0x66666654},	/* -nan=f(2.3)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x400fffff, 0xffffffee},	/* -nan=f(4)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x4016cccc, 0xccccccc4},	/* -nan=f(5.7)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x401d9999, 0x99999991},	/* -nan=f(7.4)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40223333, 0x3333332f},	/* -nan=f(9.1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40259999, 0x99999995},	/* -nan=f(10.8)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x4028ffff, 0xfffffffb},	/* -nan=f(12.5)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x402c6666, 0x66666661},	/* -nan=f(14.2)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x402fcccc, 0xccccccc7},	/* -nan=f(15.9)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40319999, 0x99999997},	/* -nan=f(17.6)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40334ccc, 0xccccccca},	/* -nan=f(19.3)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x4034ffff, 0xfffffffd},	/* -nan=f(21)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x4036b333, 0x33333330},	/* -nan=f(22.7)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x40386666, 0x66666663},	/* -nan=f(24.4)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403a1999, 0x99999996},	/* -nan=f(26.1)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* -nan=f(27.8)*/
{ 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* -nan=f(29.5)*/
{0},
};
void test_atanhf(int m)   {run_vector_1(m,atanhf_vec,(char *)(atanhf),"atanhf","ff");   }	
